aboutsummaryrefslogtreecommitdiff
path: root/devel/bcpp/files
diff options
context:
space:
mode:
authorYing-Chieh Liao <ijliao@FreeBSD.org>2001-12-19 03:52:40 +0000
committerYing-Chieh Liao <ijliao@FreeBSD.org>2001-12-19 03:52:40 +0000
commitae7cc0cc5cedd28a2cc0d437b838622bb434e353 (patch)
tree2bc96ebbd75369ab5368fba7d7e83e63439b08a2 /devel/bcpp/files
parentecefb5ebe956e1524bd701a824a5000d80681a7a (diff)
downloadports-ae7cc0cc5cedd28a2cc0d437b838622bb434e353.tar.gz
ports-ae7cc0cc5cedd28a2cc0d437b838622bb434e353.zip
Notes
Diffstat (limited to 'devel/bcpp/files')
-rw-r--r--devel/bcpp/files/patch-bcpp.cpp28
1 files changed, 22 insertions, 6 deletions
diff --git a/devel/bcpp/files/patch-bcpp.cpp b/devel/bcpp/files/patch-bcpp.cpp
index f270b0c8e252..dd7ea979df9d 100644
--- a/devel/bcpp/files/patch-bcpp.cpp
+++ b/devel/bcpp/files/patch-bcpp.cpp
@@ -1,20 +1,36 @@
--- bcpp.cpp.orig Tue Aug 10 20:54:52 1999
-+++ bcpp.cpp Wed Nov 7 10:48:27 2001
-@@ -2721,6 +2721,7 @@
++++ bcpp.cpp Tue Dec 18 20:22:18 2001
+@@ -1431,6 +1431,7 @@
+
+ }
+
++/*
+ // purge an Indent-stack
+ static void freeIndentStack(StackList* pImode)
+ {
+@@ -1451,6 +1452,7 @@
+ dst -> push(temp);
+ }
+ }
++*/
+
+ // no extra indent immediately after any brace
+ void resetSingleIndent(StackList* pIMode)
+@@ -2721,6 +2723,7 @@
char* pSPath = getenv ("PATH");
char* pEPath = NULL;
char* pNameMem = NULL;
-+ char* tmpCfgName = new char[ 16 + strlen(pCfgName) + 1];
++ char* tmpCfgName = new char[strlen("%%PREFIX%%/etc")+strlen(pCfgName)+1];
char sepChar = NULLC;
const char* pathSepChar;
char backUp;
-@@ -2729,6 +2730,13 @@
+@@ -2729,6 +2732,13 @@
// test to see if file is in current directory first !
if ((pCfgFile = fopen(pCfgName, "r")) != NULL)
return;
+
-+ // look to see if it's in /usr/local/etc
-+ tmpCfgName = strcat( tmpCfgName, "/usr/local/etc/" );
++ // look to see if it's in %%PREFIX%%/etc
++ tmpCfgName = strcat( tmpCfgName, "%%PREFIX%%/etc/" );
+ tmpCfgName = strcat( tmpCfgName, pCfgName );
+ if ((pCfgFile = fopen(tmpCfgName, "r")) != NULL)
+ return;